# NOTE: you must rebuild the samba and sssd packages after updating this one

%global __brp_check_rpaths %nil

%define ldbmajor          2
%define libldb            %mklibname ldb %{ldbmajor}
%define ldbdevel          %mklibname ldb -d

%define pyldbmajor        2
%define libpyldbutil      %mklibname pyldb-util %{pyldbmajor}
%define libpyldbutildevel %mklibname pyldb-util -d

%define check_sig() export GNUPGHOME=%{_tmppath}/rpm-gpghome \
if [ -d "$GNUPGHOME" ] \
then echo "Error, GNUPGHOME $GNUPGHOME exists, remove it and try again"; exit 1 \
fi \
install -d -m700 $GNUPGHOME \
gpg --import %{1} \
gpg --trust-model always --verify %{2} %{?3} \
rm -Rf $GNUPGHOME \

# lmdb is not supported on 32 bit architectures
%if (0%{?__isa_bits} == 64)
%global with_lmdb 1
%else
%global without_lmdb_flags --without-ldb-lmdb
%endif

%global tdb_version 1.4.9
%global tevent_version 0.15.0
%global talloc_version 2.4.1

Name:          ldb
Epoch:         1
Version:       2.8.0
Release:       %mkrel 2
Summary:       Library implementing Samba's embedded database
Group:         System/Libraries
License:       GPLv2
URL:           https://ldb.samba.org/
Source0:       https://samba.org/ftp/ldb/ldb-%{version}.tar.gz
Source1:       https://samba.org/ftp/ldb/ldb-%{version}.tar.asc
Source2:       jelmer.asc
BuildRequires: openldap-devel
BuildRequires: pkgconfig(cmocka) >= 1.1.3
BuildRequires: pkgconfig(popt)
BuildRequires: pkgconfig(tevent) >= %{tevent_version}
BuildRequires: pkgconfig(talloc) >= %{talloc_version}
BuildRequires: pytalloc-util-devel >= %{talloc_version}
BuildRequires: pkgconfig(tdb) >= %{tdb_version}
BuildRequires: pkgconfig(python3)
BuildRequires: python3-tdb >= 1:%{tdb_version}
BuildRequires: python3-talloc >= 1:%{talloc_version}
BuildRequires: python3-tevent >= 1:%{tevent_version}
BuildRequires: xsltproc
%if 0%{?with_lmdb}
BuildRequires: lmdb-devel >= 0.9.16
%endif
BuildRequires: docbook-style-xsl

%description
Library implementing Samba's embedded database and utilities for backing up,
restoring and manipulating the database.

%package -n %{libldb}
Group:         System/Libraries
Summary:       Library implementing Samba's embedded database

%description -n %{libldb}
Library implementing Samba's embedded database.

%package -n ldb-utils
Group:         Databases
Summary:       Tools for backing up, restoring, and manipulating Samba's embedded database

%description -n ldb-utils
Tools for backing up, restoring, and manipulating Samba's embedded database.

%package -n %{ldbdevel}
Group:         Development/C
Summary:       Library implementing Samba's embedded database
Provides:      ldb-devel = %{epoch}:%{version}-%{release}
Requires:      %{libldb} = %{epoch}:%{version}-%{release}

%description -n %{ldbdevel}
Library implementing Samba's embedded database.

%package -n python3-ldb
Summary: Python 3 bindings for the LDB library
Requires: python3-tdb%{?_isa} >= %{tdb_version}
%{?python_provide:%python_provide python3-ldb}

%description -n python3-ldb
Python 3 bindings for the LDB library.

%package -n %{libpyldbutil}
Group:         System/Libraries
Summary:       Utility library for using tdb functions in python 3

# ease upgrade
Conflicts:     python3-ldb < 1:1.5.5-3

%description -n %{libpyldbutil}
Utility library for using tdb functions in python 3.

%package -n %{libpyldbutildevel}
Group:         Development/Python
Summary:       Development files for utility library for using tdb functions in python 3
Provides:      pyldb-util-devel = %{epoch}:%{version}-%{release}
Requires:      %{libpyldbutil} = %{epoch}:%{version}
Requires:      %{ldbdevel} = %{epoch}:%{version}-%{release}

# ease upgrade
Conflicts:     %{_lib}ldb-devel < 1:1.5.5-3

%description -n %{libpyldbutildevel}
Development files for utility library for using tdb functions in python 3.

%prep
%setup -q
%autopatch -p1

perl -pi -e 's,http://docbook.sourceforge.net/release/xsl/current,/usr/share/sgml/docbook/xsl-stylesheets,g' docs/builddocs.sh buildtools/wafsamba/wafsamba.py buildtools/wafsamba/samba_conftests.py

# replace removed time.clock()
sed -i -e "s,time\.clock(),time.perf_counter(),g" buildtools/wafsamba/samba_deps.py

# fix for python3.8
sed -i -e "/all_flags/s,\('--libs'\),\1\, '--embed'," third_party/waf/waflib/Tools/python.py

cp -a ABI/ldb-2.6.1.sigs ABI/ldb-2.6.2.sigs

%build
%configure --disable-rpath --disable-rpath-install \
           --bundled-libraries=NONE \
           --with-modulesdir=%{_libdir} \
	   %{?without_lmdb_flags}
%make_build

%install
%make_install

%files -n %{libldb}
%{_libdir}/libldb.so.%{ldbmajor}{,.*}
%dir %{_libdir}/ldb/
%{_libdir}/ldb/asq.so
%{_libdir}/ldb/ldap.so
%{_libdir}/ldb/paged_searches.so
%{_libdir}/ldb/rdn_name.so
%{_libdir}/ldb/sample.so
%{_libdir}/ldb/server_sort.so
%{_libdir}/ldb/skel.so
%{_libdir}/ldb/tdb.so
%{_libdir}/ldb/ldb.so
%if 0%{?with_lmdb}
%{_libdir}/ldb/mdb.so
%endif

%files -n %{ldbdevel}
%{_libdir}/libldb.so
%{_libdir}/pkgconfig/ldb.pc
%{_includedir}/ldb*.h

%files -n ldb-utils
%{_bindir}/ldb*
%{_libdir}/ldb/libldb-*.so
%{_mandir}/man1/ldb*.1%{_extension}
%{_mandir}/man3/ldb*.3%{_extension}

%files -n python3-ldb
%{python3_sitearch}/ldb.cpython-*.so
%{python3_sitearch}/_ldb_text.py
%{python3_sitearch}/__pycache__/_ldb_text.cpython-*.py*

%files -n %{libpyldbutil}
%{_libdir}/libpyldb-util.cpython-*.so.%{pyldbmajor}{,.*}

%files -n %{libpyldbutildevel}
%{_libdir}/libpyldb-util.cpython-*.so
%{_includedir}/pyldb.h
%{_libdir}/pkgconfig/pyldb-util.cpython-*.pc


%changelog
* Mon Dec 25 2023 joequant <joequant> 1:2.8.0-2.mga10
+ Revision: 2021288
- rebuild for py3.12

* Sat Sep 09 2023 buchan <buchan> 1:2.8.0-1.mga10
+ Revision: 1985631
- Update to 2.8.0

* Sat Apr 01 2023 buchan <buchan> 1:2.6.2-1.mga9
+ Revision: 1951160
- Update to 2.6.2 (mga#31735)

* Sun Oct 30 2022 buchan <buchan> 1:2.6.1-1.mga9
+ Revision: 1900564
- Upgrade to 2.6.1 for samba 4.17.x
- Tighten talloc and tevent dependencies

* Sat Jul 30 2022 buchan <buchan> 1:2.5.2-1.mga9
+ Revision: 1873582
- Update to 2.5.2

* Thu Jun 16 2022 buchan <buchan> 1:2.5.1-1.mga9
+ Revision: 1864617
- Update to 2.5.1

* Sun Mar 27 2022 buchan <buchan> 1:2.5.0-1.mga9
+ Revision: 1829463
- Update to 2.5.0

* Tue Mar 15 2022 luigiwalser <luigiwalser> 1:2.4.2-1.mga9
+ Revision: 1793732
- 2.4.2

* Sat Feb 12 2022 tv <tv> 1:2.4.1-2.mga9
+ Revision: 1773670
- Rebuild for python-3.10

* Fri Nov 05 2021 luigiwalser <luigiwalser> 1:2.4.1-1.mga9
+ Revision: 1754021
- 2.4.1

* Tue Aug 31 2021 buchan <buchan> 1:2.4.0-1.mga9
+ Revision: 1743671
- New version 2.4.0

* Mon May 03 2021 neoclust <neoclust> 1:2.3.0-1.mga9
+ Revision: 1721123
- New version 2.3.0

* Tue Mar 16 2021 tmb <tmb> 1:2.2.0-2.mga9
+ Revision: 1703823
- rebuild for python 3.9

* Sun Feb 28 2021 buchan <buchan> 1:2.2.0-1.mga9
+ Revision: 1693564
- Update to 2.2.0

* Sun Jul 05 2020 buchan <buchan> 1:2.1.4-1.mga8
+ Revision: 1602407
- Update to 2.1.4

* Wed May 27 2020 luigiwalser <luigiwalser> 1:2.1.3-1.mga8
+ Revision: 1588101
- 2.1.3

* Wed Apr 29 2020 buchan <buchan> 1:2.1.2-2.mga8
+ Revision: 1573328
- Update to 2.1.2

* Sat Apr 18 2020 buchan <buchan> 1:2.1.1-2.mga8
+ Revision: 1568917
- Update to 2.1.1

* Tue Feb 18 2020 umeabot <umeabot> 1:1.5.6-2.mga8
+ Revision: 1539928
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Dec 14 2019 buchan <buchan> 1:1.5.6-1.mga8
+ Revision: 1467228
- Update to 1.5.6

* Sat Nov 09 2019 pterjan <pterjan> 1:1.5.5-7.mga8
+ Revision: 1458968
- Rebuild to fix incorrect dependency on armv7hl due to wrong _isa

* Fri Oct 18 2019 pterjan <pterjan> 1:1.5.5-6.mga8
+ Revision: 1454551
- Fix build

* Mon Sep 16 2019 daviddavid <daviddavid> 1:1.5.5-5.mga8
+ Revision: 1442131
- use BR pytalloc-util-devel instead

* Mon Sep 16 2019 daviddavid <daviddavid> 1:1.5.5-4.mga8
+ Revision: 1442130
- let pyldb-util pkgconfig .pc file name as it should

* Mon Sep 16 2019 daviddavid <daviddavid> 1:1.5.5-3.mga8
+ Revision: 1442075
- library and devel pyldb-util should be in their own subpkgs
- fix pyldb-util pkgconfig .pc file

* Wed Sep 11 2019 tv <tv> 1:1.5.5-2.mga8
+ Revision: 1439844
- rebuild for python-3.8
- drop python2 subpkg

* Sun Aug 18 2019 buchan <buchan> 1:1.5.5-1.mga8
+ Revision: 1429891
- Update to 1.5.5

* Sat Mar 09 2019 luigiwalser <luigiwalser> 1:1.5.4-1.mga7
+ Revision: 1372999
- 1.5.4
- remove unnecessary patches

* Sun Jan 20 2019 luigiwalser <luigiwalser> 1:1.5.2-1.mga7
+ Revision: 1358431
- 1.5.2
- add four patches from fedora
- pathfix is no longer used
- python3 is now the default and python2 is the extra-python
- fix hardcoded path to waf (from fedora)
- explicitly disable lmdb on 32-bit architectures

* Mon Jan 07 2019 zezinho <zezinho> 1:1.4.3-3.mga7
+ Revision: 1351112
- rebuild for python3.7

* Wed Nov 28 2018 tv <tv> 1:1.4.3-2.mga7
+ Revision: 1336444
- enable python3 support

* Sun Nov 18 2018 kekepower <kekepower> 1:1.4.3-1.mga7
+ Revision: 1331072
- Update to version 1.4.3

* Sun Oct 28 2018 daviddavid <daviddavid> 1:1.4.2-2.mga7
+ Revision: 1326438
- rename python-ldb to python2-ldb

* Fri Oct 26 2018 bcornec <bcornec> 1:1.4.2-1.mga7
+ Revision: 1325992
- lmdb not active on i586
- ldb requires a more recent lmdb-devel to build
- ldb version should be less than 1.5 for samba 4.9.1
- update to upstream ldb-1.5.1 needed to update samba 4.9.1

* Fri Oct 26 2018 bcornec <bcornec> 1:1.3.5-1.mga7
+ Revision: 1325585
- update to upstream ldb-1.3.5 to fix mga#23445

* Sun Sep 23 2018 umeabot <umeabot> 1:1.3.2-2.mga7
+ Revision: 1298725
- Mageia 7 Mass Rebuild

* Thu Apr 05 2018 buchan <buchan> 1:1.3.2-1.mga7
+ Revision: 1215509
- BR tevent 0.9.36
+ kekepower <kekepower>
- Update to version 1.3.2

* Fri Jan 26 2018 luigiwalser <luigiwalser> 1:1.3.1-1.mga7
+ Revision: 1197215
- 1.3.1

* Wed Jan 03 2018 wally <wally> 1:1.3.0-2.mga7
+ Revision: 1190003
- fix dangling symlink (mga#22301)
- drop old conflicts

* Tue Jan 02 2018 wally <wally> 1:1.3.0-1.mga7
+ Revision: 1189693
- drop pyevent check patch
- add mem leak patch via Fedora
- BR cmocka
- fix BRs (pkgconfig style BRs doesn't have epoch in their parsed version tag)
+ neoclust <neoclust>
- New version 1.3.0

* Wed Dec 07 2016 luigiwalser <luigiwalser> 1:1.1.29-1.mga6
+ Revision: 1073057
- 1.1.29

* Thu Aug 11 2016 luigiwalser <luigiwalser> 1:1.1.27-1.mga6
+ Revision: 1045501
- 1.1.27

* Thu Feb 25 2016 luigiwalser <luigiwalser> 1:1.1.26-1.mga6
+ Revision: 979019
- 1.1.26

* Sun Dec 27 2015 neoclust <neoclust> 1:1.1.25-1.mga6
+ Revision: 915721
- New version 1.1.25

* Fri Sep 25 2015 sander85 <sander85> 1:1.1.21-1.mga6
+ Revision: 883633
- New version: 1.1.21

* Fri Aug 21 2015 tmb <tmb> 1:1.1.20-2.mga6
+ Revision: 867617
- rebuild for new gcc

* Sun Jun 21 2015 luigiwalser <luigiwalser> 1:1.1.20-1.mga6
+ Revision: 836991
- 1.1.20

* Wed Oct 15 2014 umeabot <umeabot> 1:1.1.17-4.mga5
+ Revision: 744770
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1:1.1.17-3.mga5
+ Revision: 726690
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1:1.1.17-2.mga5
+ Revision: 681288
- Mageia 5 Mass Rebuild

* Fri May 09 2014 luigiwalser <luigiwalser> 1:1.1.17-1.mga5
+ Revision: 621600
- 1.1.17

* Sat Oct 19 2013 umeabot <umeabot> 1:1.1.16-2.mga4
+ Revision: 533092
- Mageia 4 Mass Rebuild

* Sun Aug 25 2013 luigiwalser <luigiwalser> 1:1.1.16-1.mga4
+ Revision: 471524
- 1.1.16

* Fri May 24 2013 luigiwalser <luigiwalser> 1:1.1.15-3.mga4
+ Revision: 426744
- 1.1.15

* Thu Mar 14 2013 guillomovitch <guillomovitch> 1:1.1.14-3.mga3
+ Revision: 403214
- ship the backends in the lib package, as they are useless otherwise

* Sat Jan 12 2013 umeabot <umeabot> 1:1.1.14-2.mga3
+ Revision: 356727
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 17 2012 buchan <buchan> 1:1.1.14-1.mga3
+ Revision: 332033
- New version 1.1.14
- Update version dependencies from bundled lib/*/wscript files

* Thu Aug 16 2012 fedya <fedya> 1:1.1.10-1.mga3
+ Revision: 281524
- rpmlint warning fix again on line 100
- rpmlint warning fix
- reason for disable pgp check see comment into prep section
- version update 1.1.10

* Tue Jan 10 2012 buchan <buchan> 1:1.1.4-1.mga2
+ Revision: 194482
- New version 1.1.4
- add signature checking
- disable broken version check for pytevent, exposed by preventing any lib bundling
- clean up BRs
- BR popt-devel

* Fri May 13 2011 buchan <buchan> 1:1.1.0-1.mga1
+ Revision: 97832
- Tighten tdb-devel BR
- imported package ldb


* Fri May 06 2011 Buchan Milne <bgmilne@mandriva.org> 1:1.1.0-1mdv2011.0
+ Revision: 669881
- Buildrequire tdb-devel to stop ldb building an internal copy
- buildrequire xsltproc
- Force use of local docbook stylesheets
- Buildrequire docbook-style-xsl
- import ldb

